# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/data/cluster/v2alpha/outlier_detection_event.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from udpa.annotations import migrate_pb2 as udpa_dot_annotations_dot_migrate__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='envoy/data/cluster/v2alpha/outlier_detection_event.proto',
  package='envoy.data.cluster.v2alpha',
  syntax='proto3',
  serialized_options=b'\n(io.envoyproxy.envoy.data.cluster.v2alphaB\032OutlierDetectionEventProtoP\001\362\230\376\217\005\027\022\025envoy.data.cluster.v3\272\200\310\321\006\002\020\001',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n8envoy/data/cluster/v2alpha/outlier_detection_event.proto\x12\x1a\x65nvoy.data.cluster.v2alpha\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1eudpa/annotations/migrate.proto\x1a\x1dudpa/annotations/status.proto\x1a\x17validate/validate.proto\"\x96\x05\n\x15OutlierDetectionEvent\x12G\n\x04type\x18\x01 \x01(\x0e\x32/.envoy.data.cluster.v2alpha.OutlierEjectionTypeB\x08\xfa\x42\x05\x82\x01\x02\x10\x01\x12-\n\ttimestamp\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12<\n\x16secs_since_last_action\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.UInt64Value\x12\x1d\n\x0c\x63luster_name\x18\x04 \x01(\tB\x07\xfa\x42\x04r\x02 \x01\x12\x1d\n\x0cupstream_url\x18\x05 \x01(\tB\x07\xfa\x42\x04r\x02 \x01\x12<\n\x06\x61\x63tion\x18\x06 \x01(\x0e\x32\".envoy.data.cluster.v2alpha.ActionB\x08\xfa\x42\x05\x82\x01\x02\x10\x01\x12\x15\n\rnum_ejections\x18\x07 \x01(\r\x12\x10\n\x08\x65nforced\x18\x08 \x01(\x08\x12W\n\x18\x65ject_success_rate_event\x18\t \x01(\x0b\x32\x33.envoy.data.cluster.v2alpha.OutlierEjectSuccessRateH\x00\x12V\n\x17\x65ject_consecutive_event\x18\n \x01(\x0b\x32\x33.envoy.data.cluster.v2alpha.OutlierEjectConsecutiveH\x00\x12\x63\n\x1e\x65ject_failure_percentage_event\x18\x0b \x01(\x0b\x32\x39.envoy.data.cluster.v2alpha.OutlierEjectFailurePercentageH\x00\x42\x0c\n\x05\x65vent\x12\x03\xf8\x42\x01\"\xa6\x01\n\x17OutlierEjectSuccessRate\x12\"\n\x11host_success_rate\x18\x01 \x01(\rB\x07\xfa\x42\x04*\x02\x18\x64\x12-\n\x1c\x63luster_average_success_rate\x18\x02 \x01(\rB\x07\xfa\x42\x04*\x02\x18\x64\x12\x38\n\'cluster_success_rate_ejection_threshold\x18\x03 \x01(\rB\x07\xfa\x42\x04*\x02\x18\x64\"\x19\n\x17OutlierEjectConsecutive\"C\n\x1dOutlierEjectFailurePercentage\x12\"\n\x11host_success_rate\x18\x01 \x01(\rB\x07\xfa\x42\x04*\x02\x18\x64*\xdf\x01\n\x13OutlierEjectionType\x12\x13\n\x0f\x43ONSECUTIVE_5XX\x10\x00\x12\x1f\n\x1b\x43ONSECUTIVE_GATEWAY_FAILURE\x10\x01\x12\x10\n\x0cSUCCESS_RATE\x10\x02\x12$\n CONSECUTIVE_LOCAL_ORIGIN_FAILURE\x10\x03\x12\x1d\n\x19SUCCESS_RATE_LOCAL_ORIGIN\x10\x04\x12\x16\n\x12\x46\x41ILURE_PERCENTAGE\x10\x05\x12#\n\x1f\x46\x41ILURE_PERCENTAGE_LOCAL_ORIGIN\x10\x06* \n\x06\x41\x63tion\x12\t\n\x05\x45JECT\x10\x00\x12\x0b\n\x07UNEJECT\x10\x01\x42m\n(io.envoyproxy.envoy.data.cluster.v2alphaB\x1aOutlierDetectionEventProtoP\x01\xf2\x98\xfe\x8f\x05\x17\x12\x15\x65nvoy.data.cluster.v3\xba\x80\xc8\xd1\x06\x02\x10\x01\x62\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,google_dot_protobuf_dot_wrappers__pb2.DESCRIPTOR,udpa_dot_annotations_dot_migrate__pb2.DESCRIPTOR,udpa_dot_annotations_dot_status__pb2.DESCRIPTOR,validate_dot_validate__pb2.DESCRIPTOR,])

_OUTLIEREJECTIONTYPE = _descriptor.EnumDescriptor(
  name='OutlierEjectionType',
  full_name='envoy.data.cluster.v2alpha.OutlierEjectionType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='CONSECUTIVE_5XX', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CONSECUTIVE_GATEWAY_FAILURE', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SUCCESS_RATE', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CONSECUTIVE_LOCAL_ORIGIN_FAILURE', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SUCCESS_RATE_LOCAL_ORIGIN', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FAILURE_PERCENTAGE', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FAILURE_PERCENTAGE_LOCAL_ORIGIN', index=6, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1172,
  serialized_end=1395,
)
_sym_db.RegisterEnumDescriptor(_OUTLIEREJECTIONTYPE)

OutlierEjectionType = enum_type_wrapper.EnumTypeWrapper(_OUTLIEREJECTIONTYPE)
_ACTION = _descriptor.EnumDescriptor(
  name='Action',
  full_name='envoy.data.cluster.v2alpha.Action',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='EJECT', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='UNEJECT', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1397,
  serialized_end=1429,
)
_sym_db.RegisterEnumDescriptor(_ACTION)

Action = enum_type_wrapper.EnumTypeWrapper(_ACTION)
CONSECUTIVE_5XX = 0
CONSECUTIVE_GATEWAY_FAILURE = 1
SUCCESS_RATE = 2
CONSECUTIVE_LOCAL_ORIGIN_FAILURE = 3
SUCCESS_RATE_LOCAL_ORIGIN = 4
FAILURE_PERCENTAGE = 5
FAILURE_PERCENTAGE_LOCAL_ORIGIN = 6
EJECT = 0
UNEJECT = 1



_OUTLIERDETECTIONEVENT = _descriptor.Descriptor(
  name='OutlierDetectionEvent',
  full_name='envoy.data.cluster.v2alpha.OutlierDetectionEvent',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='envoy.data.cluster.v2alpha.OutlierDetectionEvent.type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\202\001\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='envoy.data.cluster.v2alpha.OutlierDetectionEvent.timestamp', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='secs_since_last_action', full_name='envoy.data.cluster.v2alpha.OutlierDetectionEvent.secs_since_last_action', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cluster_name', full_name='envoy.data.cluster.v2alpha.OutlierDetectionEvent.cluster_name', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004r\002 \001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='upstream_url', full_name='envoy.data.cluster.v2alpha.OutlierDetectionEvent.upstream_url', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004r\002 \001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='action', full_name='envoy.data.cluster.v2alpha.OutlierDetectionEvent.action', index=5,
      number=6, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\202\001\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='num_ejections', full_name='envoy.data.cluster.v2alpha.OutlierDetectionEvent.num_ejections', index=6,
      number=7, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='enforced', full_name='envoy.data.cluster.v2alpha.OutlierDetectionEvent.enforced', index=7,
      number=8, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='eject_success_rate_event', full_name='envoy.data.cluster.v2alpha.OutlierDetectionEvent.eject_success_rate_event', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='eject_consecutive_event', full_name='envoy.data.cluster.v2alpha.OutlierDetectionEvent.eject_consecutive_event', index=9,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='eject_failure_percentage_event', full_name='envoy.data.cluster.v2alpha.OutlierDetectionEvent.eject_failure_percentage_event', index=10,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='event', full_name='envoy.data.cluster.v2alpha.OutlierDetectionEvent.event',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[], serialized_options=b'\370B\001'),
  ],
  serialized_start=242,
  serialized_end=904,
)


_OUTLIEREJECTSUCCESSRATE = _descriptor.Descriptor(
  name='OutlierEjectSuccessRate',
  full_name='envoy.data.cluster.v2alpha.OutlierEjectSuccessRate',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='host_success_rate', full_name='envoy.data.cluster.v2alpha.OutlierEjectSuccessRate.host_success_rate', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004*\002\030d', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cluster_average_success_rate', full_name='envoy.data.cluster.v2alpha.OutlierEjectSuccessRate.cluster_average_success_rate', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004*\002\030d', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cluster_success_rate_ejection_threshold', full_name='envoy.data.cluster.v2alpha.OutlierEjectSuccessRate.cluster_success_rate_ejection_threshold', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004*\002\030d', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=907,
  serialized_end=1073,
)


_OUTLIEREJECTCONSECUTIVE = _descriptor.Descriptor(
  name='OutlierEjectConsecutive',
  full_name='envoy.data.cluster.v2alpha.OutlierEjectConsecutive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1075,
  serialized_end=1100,
)


_OUTLIEREJECTFAILUREPERCENTAGE = _descriptor.Descriptor(
  name='OutlierEjectFailurePercentage',
  full_name='envoy.data.cluster.v2alpha.OutlierEjectFailurePercentage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='host_success_rate', full_name='envoy.data.cluster.v2alpha.OutlierEjectFailurePercentage.host_success_rate', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004*\002\030d', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1102,
  serialized_end=1169,
)

_OUTLIERDETECTIONEVENT.fields_by_name['type'].enum_type = _OUTLIEREJECTIONTYPE
_OUTLIERDETECTIONEVENT.fields_by_name['timestamp'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_OUTLIERDETECTIONEVENT.fields_by_name['secs_since_last_action'].message_type = google_dot_protobuf_dot_wrappers__pb2._UINT64VALUE
_OUTLIERDETECTIONEVENT.fields_by_name['action'].enum_type = _ACTION
_OUTLIERDETECTIONEVENT.fields_by_name['eject_success_rate_event'].message_type = _OUTLIEREJECTSUCCESSRATE
_OUTLIERDETECTIONEVENT.fields_by_name['eject_consecutive_event'].message_type = _OUTLIEREJECTCONSECUTIVE
_OUTLIERDETECTIONEVENT.fields_by_name['eject_failure_percentage_event'].message_type = _OUTLIEREJECTFAILUREPERCENTAGE
_OUTLIERDETECTIONEVENT.oneofs_by_name['event'].fields.append(
  _OUTLIERDETECTIONEVENT.fields_by_name['eject_success_rate_event'])
_OUTLIERDETECTIONEVENT.fields_by_name['eject_success_rate_event'].containing_oneof = _OUTLIERDETECTIONEVENT.oneofs_by_name['event']
_OUTLIERDETECTIONEVENT.oneofs_by_name['event'].fields.append(
  _OUTLIERDETECTIONEVENT.fields_by_name['eject_consecutive_event'])
_OUTLIERDETECTIONEVENT.fields_by_name['eject_consecutive_event'].containing_oneof = _OUTLIERDETECTIONEVENT.oneofs_by_name['event']
_OUTLIERDETECTIONEVENT.oneofs_by_name['event'].fields.append(
  _OUTLIERDETECTIONEVENT.fields_by_name['eject_failure_percentage_event'])
_OUTLIERDETECTIONEVENT.fields_by_name['eject_failure_percentage_event'].containing_oneof = _OUTLIERDETECTIONEVENT.oneofs_by_name['event']
DESCRIPTOR.message_types_by_name['OutlierDetectionEvent'] = _OUTLIERDETECTIONEVENT
DESCRIPTOR.message_types_by_name['OutlierEjectSuccessRate'] = _OUTLIEREJECTSUCCESSRATE
DESCRIPTOR.message_types_by_name['OutlierEjectConsecutive'] = _OUTLIEREJECTCONSECUTIVE
DESCRIPTOR.message_types_by_name['OutlierEjectFailurePercentage'] = _OUTLIEREJECTFAILUREPERCENTAGE
DESCRIPTOR.enum_types_by_name['OutlierEjectionType'] = _OUTLIEREJECTIONTYPE
DESCRIPTOR.enum_types_by_name['Action'] = _ACTION
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

OutlierDetectionEvent = _reflection.GeneratedProtocolMessageType('OutlierDetectionEvent', (_message.Message,), {
  'DESCRIPTOR' : _OUTLIERDETECTIONEVENT,
  '__module__' : 'envoy.data.cluster.v2alpha.outlier_detection_event_pb2'
  # @@protoc_insertion_point(class_scope:envoy.data.cluster.v2alpha.OutlierDetectionEvent)
  })
_sym_db.RegisterMessage(OutlierDetectionEvent)

OutlierEjectSuccessRate = _reflection.GeneratedProtocolMessageType('OutlierEjectSuccessRate', (_message.Message,), {
  'DESCRIPTOR' : _OUTLIEREJECTSUCCESSRATE,
  '__module__' : 'envoy.data.cluster.v2alpha.outlier_detection_event_pb2'
  # @@protoc_insertion_point(class_scope:envoy.data.cluster.v2alpha.OutlierEjectSuccessRate)
  })
_sym_db.RegisterMessage(OutlierEjectSuccessRate)

OutlierEjectConsecutive = _reflection.GeneratedProtocolMessageType('OutlierEjectConsecutive', (_message.Message,), {
  'DESCRIPTOR' : _OUTLIEREJECTCONSECUTIVE,
  '__module__' : 'envoy.data.cluster.v2alpha.outlier_detection_event_pb2'
  # @@protoc_insertion_point(class_scope:envoy.data.cluster.v2alpha.OutlierEjectConsecutive)
  })
_sym_db.RegisterMessage(OutlierEjectConsecutive)

OutlierEjectFailurePercentage = _reflection.GeneratedProtocolMessageType('OutlierEjectFailurePercentage', (_message.Message,), {
  'DESCRIPTOR' : _OUTLIEREJECTFAILUREPERCENTAGE,
  '__module__' : 'envoy.data.cluster.v2alpha.outlier_detection_event_pb2'
  # @@protoc_insertion_point(class_scope:envoy.data.cluster.v2alpha.OutlierEjectFailurePercentage)
  })
_sym_db.RegisterMessage(OutlierEjectFailurePercentage)


DESCRIPTOR._options = None
_OUTLIERDETECTIONEVENT.oneofs_by_name['event']._options = None
_OUTLIERDETECTIONEVENT.fields_by_name['type']._options = None
_OUTLIERDETECTIONEVENT.fields_by_name['cluster_name']._options = None
_OUTLIERDETECTIONEVENT.fields_by_name['upstream_url']._options = None
_OUTLIERDETECTIONEVENT.fields_by_name['action']._options = None
_OUTLIEREJECTSUCCESSRATE.fields_by_name['host_success_rate']._options = None
_OUTLIEREJECTSUCCESSRATE.fields_by_name['cluster_average_success_rate']._options = None
_OUTLIEREJECTSUCCESSRATE.fields_by_name['cluster_success_rate_ejection_threshold']._options = None
_OUTLIEREJECTFAILUREPERCENTAGE.fields_by_name['host_success_rate']._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/type/token_bucket.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='envoy/type/token_bucket.proto',
  package='envoy.type',
  syntax='proto3',
  serialized_options=b'\n\030io.envoyproxy.envoy.typeB\020TokenBucketProtoP\001\272\200\310\321\006\002\020\001',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x1d\x65nvoy/type/token_bucket.proto\x12\nenvoy.type\x1a\x1egoogle/protobuf/duration.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1dudpa/annotations/status.proto\x1a\x17validate/validate.proto\"\xa8\x01\n\x0bTokenBucket\x12\x1b\n\nmax_tokens\x18\x01 \x01(\rB\x07\xfa\x42\x04*\x02 \x00\x12>\n\x0ftokens_per_fill\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueB\x07\xfa\x42\x04*\x02 \x00\x12<\n\rfill_interval\x18\x03 \x01(\x0b\x32\x19.google.protobuf.DurationB\n\xfa\x42\x07\xaa\x01\x04\x08\x01*\x00\x42\x36\n\x18io.envoyproxy.envoy.typeB\x10TokenBucketProtoP\x01\xba\x80\xc8\xd1\x06\x02\x10\x01\x62\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_duration__pb2.DESCRIPTOR,google_dot_protobuf_dot_wrappers__pb2.DESCRIPTOR,udpa_dot_annotations_dot_status__pb2.DESCRIPTOR,validate_dot_validate__pb2.DESCRIPTOR,])




_TOKENBUCKET = _descriptor.Descriptor(
  name='TokenBucket',
  full_name='envoy.type.TokenBucket',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='max_tokens', full_name='envoy.type.TokenBucket.max_tokens', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004*\002 \000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tokens_per_fill', full_name='envoy.type.TokenBucket.tokens_per_fill', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004*\002 \000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='fill_interval', full_name='envoy.type.TokenBucket.fill_interval', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\007\252\001\004\010\001*\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=166,
  serialized_end=334,
)

_TOKENBUCKET.fields_by_name['tokens_per_fill'].message_type = google_dot_protobuf_dot_wrappers__pb2._UINT32VALUE
_TOKENBUCKET.fields_by_name['fill_interval'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
DESCRIPTOR.message_types_by_name['TokenBucket'] = _TOKENBUCKET
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

TokenBucket = _reflection.GeneratedProtocolMessageType('TokenBucket', (_message.Message,), {
  'DESCRIPTOR' : _TOKENBUCKET,
  '__module__' : 'envoy.type.token_bucket_pb2'
  # @@protoc_insertion_point(class_scope:envoy.type.TokenBucket)
  })
_sym_db.RegisterMessage(TokenBucket)


DESCRIPTOR._options = None
_TOKENBUCKET.fields_by_name['max_tokens']._options = None
_TOKENBUCKET.fields_by_name['tokens_per_fill']._options = None
_TOKENBUCKET.fields_by_name['fill_interval']._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/data/tap/v3/http.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.config.core.v3 import base_pb2 as envoy_dot_config_dot_core_dot_v3_dot_base__pb2
from envoy.data.tap.v3 import common_pb2 as envoy_dot_data_dot_tap_dot_v3_dot_common__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from udpa.annotations import versioning_pb2 as udpa_dot_annotations_dot_versioning__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='envoy/data/tap/v3/http.proto',
  package='envoy.data.tap.v3',
  syntax='proto3',
  serialized_options=b'\n\037io.envoyproxy.envoy.data.tap.v3B\tHttpProtoP\001\272\200\310\321\006\002\020\002',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x1c\x65nvoy/data/tap/v3/http.proto\x12\x11\x65nvoy.data.tap.v3\x1a\x1f\x65nvoy/config/core/v3/base.proto\x1a\x1e\x65nvoy/data/tap/v3/common.proto\x1a\x1dudpa/annotations/status.proto\x1a!udpa/annotations/versioning.proto\"\x98\x03\n\x11HttpBufferedTrace\x12=\n\x07request\x18\x01 \x01(\x0b\x32,.envoy.data.tap.v3.HttpBufferedTrace.Message\x12>\n\x08response\x18\x02 \x01(\x0b\x32,.envoy.data.tap.v3.HttpBufferedTrace.Message\x1a\xd2\x01\n\x07Message\x12\x32\n\x07headers\x18\x01 \x03(\x0b\x32!.envoy.config.core.v3.HeaderValue\x12%\n\x04\x62ody\x18\x02 \x01(\x0b\x32\x17.envoy.data.tap.v3.Body\x12\x33\n\x08trailers\x18\x03 \x03(\x0b\x32!.envoy.config.core.v3.HeaderValue:7\x9a\xc5\x88\x1e\x32\n0envoy.data.tap.v2alpha.HttpBufferedTrace.Message:/\x9a\xc5\x88\x1e*\n(envoy.data.tap.v2alpha.HttpBufferedTrace\"\xd8\x03\n\x18HttpStreamedTraceSegment\x12\x10\n\x08trace_id\x18\x01 \x01(\x04\x12:\n\x0frequest_headers\x18\x02 \x01(\x0b\x32\x1f.envoy.config.core.v3.HeaderMapH\x00\x12\x35\n\x12request_body_chunk\x18\x03 \x01(\x0b\x32\x17.envoy.data.tap.v3.BodyH\x00\x12;\n\x10request_trailers\x18\x04 \x01(\x0b\x32\x1f.envoy.config.core.v3.HeaderMapH\x00\x12;\n\x10response_headers\x18\x05 \x01(\x0b\x32\x1f.envoy.config.core.v3.HeaderMapH\x00\x12\x36\n\x13response_body_chunk\x18\x06 \x01(\x0b\x32\x17.envoy.data.tap.v3.BodyH\x00\x12<\n\x11response_trailers\x18\x07 \x01(\x0b\x32\x1f.envoy.config.core.v3.HeaderMapH\x00:6\x9a\xc5\x88\x1e\x31\n/envoy.data.tap.v2alpha.HttpStreamedTraceSegmentB\x0f\n\rmessage_pieceB6\n\x1fio.envoyproxy.envoy.data.tap.v3B\tHttpProtoP\x01\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3'
  ,
  dependencies=[envoy_dot_config_dot_core_dot_v3_dot_base__pb2.DESCRIPTOR,envoy_dot_data_dot_tap_dot_v3_dot_common__pb2.DESCRIPTOR,udpa_dot_annotations_dot_status__pb2.DESCRIPTOR,udpa_dot_annotations_dot_versioning__pb2.DESCRIPTOR,])




_HTTPBUFFEREDTRACE_MESSAGE = _descriptor.Descriptor(
  name='Message',
  full_name='envoy.data.tap.v3.HttpBufferedTrace.Message',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='headers', full_name='envoy.data.tap.v3.HttpBufferedTrace.Message.headers', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='body', full_name='envoy.data.tap.v3.HttpBufferedTrace.Message.body', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='trailers', full_name='envoy.data.tap.v3.HttpBufferedTrace.Message.trailers', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\0362\n0envoy.data.tap.v2alpha.HttpBufferedTrace.Message',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=332,
  serialized_end=542,
)

_HTTPBUFFEREDTRACE = _descriptor.Descriptor(
  name='HttpBufferedTrace',
  full_name='envoy.data.tap.v3.HttpBufferedTrace',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='request', full_name='envoy.data.tap.v3.HttpBufferedTrace.request', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='response', full_name='envoy.data.tap.v3.HttpBufferedTrace.response', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_HTTPBUFFEREDTRACE_MESSAGE, ],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036*\n(envoy.data.tap.v2alpha.HttpBufferedTrace',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=183,
  serialized_end=591,
)


_HTTPSTREAMEDTRACESEGMENT = _descriptor.Descriptor(
  name='HttpStreamedTraceSegment',
  full_name='envoy.data.tap.v3.HttpStreamedTraceSegment',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='trace_id', full_name='envoy.data.tap.v3.HttpStreamedTraceSegment.trace_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='request_headers', full_name='envoy.data.tap.v3.HttpStreamedTraceSegment.request_headers', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='request_body_chunk', full_name='envoy.data.tap.v3.HttpStreamedTraceSegment.request_body_chunk', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='request_trailers', full_name='envoy.data.tap.v3.HttpStreamedTraceSegment.request_trailers', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='response_headers', full_name='envoy.data.tap.v3.HttpStreamedTraceSegment.response_headers', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='response_body_chunk', full_name='envoy.data.tap.v3.HttpStreamedTraceSegment.response_body_chunk', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='response_trailers', full_name='envoy.data.tap.v3.HttpStreamedTraceSegment.response_trailers', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\0361\n/envoy.data.tap.v2alpha.HttpStreamedTraceSegment',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='message_piece', full_name='envoy.data.tap.v3.HttpStreamedTraceSegment.message_piece',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=594,
  serialized_end=1066,
)

_HTTPBUFFEREDTRACE_MESSAGE.fields_by_name['headers'].message_type = envoy_dot_config_dot_core_dot_v3_dot_base__pb2._HEADERVALUE
_HTTPBUFFEREDTRACE_MESSAGE.fields_by_name['body'].message_type = envoy_dot_data_dot_tap_dot_v3_dot_common__pb2._BODY
_HTTPBUFFEREDTRACE_MESSAGE.fields_by_name['trailers'].message_type = envoy_dot_config_dot_core_dot_v3_dot_base__pb2._HEADERVALUE
_HTTPBUFFEREDTRACE_MESSAGE.containing_type = _HTTPBUFFEREDTRACE
_HTTPBUFFEREDTRACE.fields_by_name['request'].message_type = _HTTPBUFFEREDTRACE_MESSAGE
_HTTPBUFFEREDTRACE.fields_by_name['response'].message_type = _HTTPBUFFEREDTRACE_MESSAGE
_HTTPSTREAMEDTRACESEGMENT.fields_by_name['request_headers'].message_type = envoy_dot_config_dot_core_dot_v3_dot_base__pb2._HEADERMAP
_HTTPSTREAMEDTRACESEGMENT.fields_by_name['request_body_chunk'].message_type = envoy_dot_data_dot_tap_dot_v3_dot_common__pb2._BODY
_HTTPSTREAMEDTRACESEGMENT.fields_by_name['request_trailers'].message_type = envoy_dot_config_dot_core_dot_v3_dot_base__pb2._HEADERMAP
_HTTPSTREAMEDTRACESEGMENT.fields_by_name['response_headers'].message_type = envoy_dot_config_dot_core_dot_v3_dot_base__pb2._HEADERMAP
_HTTPSTREAMEDTRACESEGMENT.fields_by_name['response_body_chunk'].message_type = envoy_dot_data_dot_tap_dot_v3_dot_common__pb2._BODY
_HTTPSTREAMEDTRACESEGMENT.fields_by_name['response_trailers'].message_type = envoy_dot_config_dot_core_dot_v3_dot_base__pb2._HEADERMAP
_HTTPSTREAMEDTRACESEGMENT.oneofs_by_name['message_piece'].fields.append(
  _HTTPSTREAMEDTRACESEGMENT.fields_by_name['request_headers'])
_HTTPSTREAMEDTRACESEGMENT.fields_by_name['request_headers'].containing_oneof = _HTTPSTREAMEDTRACESEGMENT.oneofs_by_name['message_piece']
_HTTPSTREAMEDTRACESEGMENT.oneofs_by_name['message_piece'].fields.append(
  _HTTPSTREAMEDTRACESEGMENT.fields_by_name['request_body_chunk'])
_HTTPSTREAMEDTRACESEGMENT.fields_by_name['request_body_chunk'].containing_oneof = _HTTPSTREAMEDTRACESEGMENT.oneofs_by_name['message_piece']
_HTTPSTREAMEDTRACESEGMENT.oneofs_by_name['message_piece'].fields.append(
  _HTTPSTREAMEDTRACESEGMENT.fields_by_name['request_trailers'])
_HTTPSTREAMEDTRACESEGMENT.fields_by_name['request_trailers'].containing_oneof = _HTTPSTREAMEDTRACESEGMENT.oneofs_by_name['message_piece']
_HTTPSTREAMEDTRACESEGMENT.oneofs_by_name['message_piece'].fields.append(
  _HTTPSTREAMEDTRACESEGMENT.fields_by_name['response_headers'])
_HTTPSTREAMEDTRACESEGMENT.fields_by_name['response_headers'].containing_oneof = _HTTPSTREAMEDTRACESEGMENT.oneofs_by_name['message_piece']
_HTTPSTREAMEDTRACESEGMENT.oneofs_by_name['message_piece'].fields.append(
  _HTTPSTREAMEDTRACESEGMENT.fields_by_name['response_body_chunk'])
_HTTPSTREAMEDTRACESEGMENT.fields_by_name['response_body_chunk'].containing_oneof = _HTTPSTREAMEDTRACESEGMENT.oneofs_by_name['message_piece']
_HTTPSTREAMEDTRACESEGMENT.oneofs_by_name['message_piece'].fields.append(
  _HTTPSTREAMEDTRACESEGMENT.fields_by_name['response_trailers'])
_HTTPSTREAMEDTRACESEGMENT.fields_by_name['response_trailers'].containing_oneof = _HTTPSTREAMEDTRACESEGMENT.oneofs_by_name['message_piece']
DESCRIPTOR.message_types_by_name['HttpBufferedTrace'] = _HTTPBUFFEREDTRACE
DESCRIPTOR.message_types_by_name['HttpStreamedTraceSegment'] = _HTTPSTREAMEDTRACESEGMENT
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

HttpBufferedTrace = _reflection.GeneratedProtocolMessageType('HttpBufferedTrace', (_message.Message,), {

  'Message' : _reflection.GeneratedProtocolMessageType('Message', (_message.Message,), {
    'DESCRIPTOR' : _HTTPBUFFEREDTRACE_MESSAGE,
    '__module__' : 'envoy.data.tap.v3.http_pb2'
    # @@protoc_insertion_point(class_scope:envoy.data.tap.v3.HttpBufferedTrace.Message)
    })
  ,
  'DESCRIPTOR' : _HTTPBUFFEREDTRACE,
  '__module__' : 'envoy.data.tap.v3.http_pb2'
  # @@protoc_insertion_point(class_scope:envoy.data.tap.v3.HttpBufferedTrace)
  })
_sym_db.RegisterMessage(HttpBufferedTrace)
_sym_db.RegisterMessage(HttpBufferedTrace.Message)

HttpStreamedTraceSegment = _reflection.GeneratedProtocolMessageType('HttpStreamedTraceSegment', (_message.Message,), {
  'DESCRIPTOR' : _HTTPSTREAMEDTRACESEGMENT,
  '__module__' : 'envoy.data.tap.v3.http_pb2'
  # @@protoc_insertion_point(class_scope:envoy.data.tap.v3.HttpStreamedTraceSegment)
  })
_sym_db.RegisterMessage(HttpStreamedTraceSegment)


DESCRIPTOR._options = None
_HTTPBUFFEREDTRACE_MESSAGE._options = None
_HTTPBUFFEREDTRACE._options = None
_HTTPSTREAMEDTRACESEGMENT._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/extensions/filters/network/rbac/v3/rbac.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.config.rbac.v3 import rbac_pb2 as envoy_dot_config_dot_rbac_dot_v3_dot_rbac__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from udpa.annotations import versioning_pb2 as udpa_dot_annotations_dot_versioning__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='envoy/extensions/filters/network/rbac/v3/rbac.proto',
  package='envoy.extensions.filters.network.rbac.v3',
  syntax='proto3',
  serialized_options=b'\n6io.envoyproxy.envoy.extensions.filters.network.rbac.v3B\tRbacProtoP\001\272\200\310\321\006\002\020\002',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n3envoy/extensions/filters/network/rbac/v3/rbac.proto\x12(envoy.extensions.filters.network.rbac.v3\x1a\x1f\x65nvoy/config/rbac/v3/rbac.proto\x1a\x1dudpa/annotations/status.proto\x1a!udpa/annotations/versioning.proto\x1a\x17validate/validate.proto\"\xcb\x02\n\x04RBAC\x12)\n\x05rules\x18\x01 \x01(\x0b\x32\x1a.envoy.config.rbac.v3.RBAC\x12\x30\n\x0cshadow_rules\x18\x02 \x01(\x0b\x32\x1a.envoy.config.rbac.v3.RBAC\x12\x1c\n\x0bstat_prefix\x18\x03 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12X\n\x10\x65nforcement_type\x18\x04 \x01(\x0e\x32>.envoy.extensions.filters.network.rbac.v3.RBAC.EnforcementType\"=\n\x0f\x45nforcementType\x12\x1a\n\x16ONE_TIME_ON_FIRST_BYTE\x10\x00\x12\x0e\n\nCONTINUOUS\x10\x01:/\x9a\xc5\x88\x1e*\n(envoy.config.filter.network.rbac.v2.RBACBM\n6io.envoyproxy.envoy.extensions.filters.network.rbac.v3B\tRbacProtoP\x01\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3'
  ,
  dependencies=[envoy_dot_config_dot_rbac_dot_v3_dot_rbac__pb2.DESCRIPTOR,udpa_dot_annotations_dot_status__pb2.DESCRIPTOR,udpa_dot_annotations_dot_versioning__pb2.DESCRIPTOR,validate_dot_validate__pb2.DESCRIPTOR,])



_RBAC_ENFORCEMENTTYPE = _descriptor.EnumDescriptor(
  name='EnforcementType',
  full_name='envoy.extensions.filters.network.rbac.v3.RBAC.EnforcementType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='ONE_TIME_ON_FIRST_BYTE', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CONTINUOUS', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=443,
  serialized_end=504,
)
_sym_db.RegisterEnumDescriptor(_RBAC_ENFORCEMENTTYPE)


_RBAC = _descriptor.Descriptor(
  name='RBAC',
  full_name='envoy.extensions.filters.network.rbac.v3.RBAC',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='rules', full_name='envoy.extensions.filters.network.rbac.v3.RBAC.rules', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='shadow_rules', full_name='envoy.extensions.filters.network.rbac.v3.RBAC.shadow_rules', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stat_prefix', full_name='envoy.extensions.filters.network.rbac.v3.RBAC.stat_prefix', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004r\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='enforcement_type', full_name='envoy.extensions.filters.network.rbac.v3.RBAC.enforcement_type', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _RBAC_ENFORCEMENTTYPE,
  ],
  serialized_options=b'\232\305\210\036*\n(envoy.config.filter.network.rbac.v2.RBAC',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=222,
  serialized_end=553,
)

_RBAC.fields_by_name['rules'].message_type = envoy_dot_config_dot_rbac_dot_v3_dot_rbac__pb2._RBAC
_RBAC.fields_by_name['shadow_rules'].message_type = envoy_dot_config_dot_rbac_dot_v3_dot_rbac__pb2._RBAC
_RBAC.fields_by_name['enforcement_type'].enum_type = _RBAC_ENFORCEMENTTYPE
_RBAC_ENFORCEMENTTYPE.containing_type = _RBAC
DESCRIPTOR.message_types_by_name['RBAC'] = _RBAC
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

RBAC = _reflection.GeneratedProtocolMessageType('RBAC', (_message.Message,), {
  'DESCRIPTOR' : _RBAC,
  '__module__' : 'envoy.extensions.filters.network.rbac.v3.rbac_pb2'
  # @@protoc_insertion_point(class_scope:envoy.extensions.filters.network.rbac.v3.RBAC)
  })
_sym_db.RegisterMessage(RBAC)


DESCRIPTOR._options = None
_RBAC.fields_by_name['stat_prefix']._options = None
_RBAC._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/config/core/v3/protocol.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.type.v3 import percent_pb2 as envoy_dot_type_dot_v3_dot_percent__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from udpa.annotations import versioning_pb2 as udpa_dot_annotations_dot_versioning__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='envoy/config/core/v3/protocol.proto',
  package='envoy.config.core.v3',
  syntax='proto3',
  serialized_options=b'\n\"io.envoyproxy.envoy.config.core.v3B\rProtocolProtoP\001\272\200\310\321\006\002\020\002',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n#envoy/config/core/v3/protocol.proto\x12\x14\x65nvoy.config.core.v3\x1a\x1b\x65nvoy/type/v3/percent.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1dudpa/annotations/status.proto\x1a!udpa/annotations/versioning.proto\x1a\x17validate/validate.proto\"A\n\x12TcpProtocolOptions:+\x9a\xc5\x88\x1e&\n$envoy.api.v2.core.TcpProtocolOptions\"\x82\x01\n\x1bUpstreamHttpProtocolOptions\x12\x10\n\x08\x61uto_sni\x18\x01 \x01(\x08\x12\x1b\n\x13\x61uto_san_validation\x18\x02 \x01(\x08:4\x9a\xc5\x88\x1e/\n-envoy.api.v2.core.UpstreamHttpProtocolOptions\"\xeb\x03\n\x13HttpProtocolOptions\x12/\n\x0cidle_timeout\x18\x01 \x01(\x0b\x32\x19.google.protobuf.Duration\x12:\n\x17max_connection_duration\x18\x03 \x01(\x0b\x32\x19.google.protobuf.Duration\x12@\n\x11max_headers_count\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueB\x07\xfa\x42\x04*\x02(\x01\x12\x36\n\x13max_stream_duration\x18\x04 \x01(\x0b\x32\x19.google.protobuf.Duration\x12o\n\x1fheaders_with_underscores_action\x18\x05 \x01(\x0e\x32\x46.envoy.config.core.v3.HttpProtocolOptions.HeadersWithUnderscoresAction\"N\n\x1cHeadersWithUnderscoresAction\x12\t\n\x05\x41LLOW\x10\x00\x12\x12\n\x0eREJECT_REQUEST\x10\x01\x12\x0f\n\x0b\x44ROP_HEADER\x10\x02:,\x9a\xc5\x88\x1e\'\n%envoy.api.v2.core.HttpProtocolOptions\"\xcc\x05\n\x14Http1ProtocolOptions\x12\x36\n\x12\x61llow_absolute_url\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x16\n\x0e\x61\x63\x63\x65pt_http_10\x18\x02 \x01(\x08\x12 \n\x18\x64\x65\x66\x61ult_host_for_http_10\x18\x03 \x01(\t\x12U\n\x11header_key_format\x18\x04 \x01(\x0b\x32:.envoy.config.core.v3.Http1ProtocolOptions.HeaderKeyFormat\x12\x17\n\x0f\x65nable_trailers\x18\x05 \x01(\x08\x12\x1c\n\x14\x61llow_chunked_length\x18\x06 \x01(\x08\x12Q\n-override_stream_error_on_invalid_http_message\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x1a\xb1\x02\n\x0fHeaderKeyFormat\x12g\n\x11proper_case_words\x18\x01 \x01(\x0b\x32J.envoy.config.core.v3.Http1ProtocolOptions.HeaderKeyFormat.ProperCaseWordsH\x00\x1a`\n\x0fProperCaseWords:M\x9a\xc5\x88\x1eH\nFenvoy.api.v2.core.Http1ProtocolOptions.HeaderKeyFormat.ProperCaseWords:=\x9a\xc5\x88\x1e\x38\n6envoy.api.v2.core.Http1ProtocolOptions.HeaderKeyFormatB\x14\n\rheader_format\x12\x03\xf8\x42\x01:-\x9a\xc5\x88\x1e(\n&envoy.api.v2.core.Http1ProtocolOptions\"\xbd\x01\n\x11KeepaliveSettings\x12;\n\x08interval\x18\x01 \x01(\x0b\x32\x19.google.protobuf.DurationB\x0e\xfa\x42\x0b\xaa\x01\x08\x08\x01\x32\x04\x10\xc0\x84=\x12:\n\x07timeout\x18\x02 \x01(\x0b\x32\x19.google.protobuf.DurationB\x0e\xfa\x42\x0b\xaa\x01\x08\x08\x01\x32\x04\x10\xc0\x84=\x12/\n\x0finterval_jitter\x18\x03 \x01(\x0b\x32\x16.envoy.type.v3.Percent\"\xc4\n\n\x14Http2ProtocolOptions\x12\x36\n\x10hpack_table_size\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.UInt32Value\x12K\n\x16max_concurrent_streams\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueB\r\xfa\x42\n*\x08\x18\xff\xff\xff\xff\x07(\x01\x12Q\n\x1ainitial_stream_window_size\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueB\x0f\xfa\x42\x0c*\n\x18\xff\xff\xff\xff\x07(\xff\xff\x03\x12U\n\x1einitial_connection_window_size\x18\x04 \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueB\x0f\xfa\x42\x0c*\n\x18\xff\xff\xff\xff\x07(\xff\xff\x03\x12\x15\n\rallow_connect\x18\x05 \x01(\x08\x12\x16\n\x0e\x61llow_metadata\x18\x06 \x01(\x08\x12\x42\n\x13max_outbound_frames\x18\x07 \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueB\x07\xfa\x42\x04*\x02(\x01\x12J\n\x1bmax_outbound_control_frames\x18\x08 \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueB\x07\xfa\x42\x04*\x02(\x01\x12W\n1max_consecutive_inbound_frames_with_empty_payload\x18\t \x01(\x0b\x32\x1c.google.protobuf.UInt32Value\x12L\n&max_inbound_priority_frames_per_stream\x18\n \x01(\x0b\x32\x1c.google.protobuf.UInt32Value\x12\x63\n4max_inbound_window_update_frames_per_data_frame_sent\x18\x0b \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueB\x07\xfa\x42\x04*\x02(\x01\x12\x32\n&stream_error_on_invalid_http_messaging\x18\x0c \x01(\x08\x42\x02\x18\x01\x12Q\n-override_stream_error_on_invalid_http_message\x18\x0e \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12`\n\x1a\x63ustom_settings_parameters\x18\r \x03(\x0b\x32<.envoy.config.core.v3.Http2ProtocolOptions.SettingsParameter\x12\x45\n\x14\x63onnection_keepalive\x18\x0f \x01(\x0b\x32\'.envoy.config.core.v3.KeepaliveSettings\x1a\xd2\x01\n\x11SettingsParameter\x12\x45\n\nidentifier\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueB\x13\xfa\x42\x08*\x06\x18\xff\xff\x03(\x00\xfa\x42\x05\x8a\x01\x02\x10\x01\x12\x35\n\x05value\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01:?\x9a\xc5\x88\x1e:\n8envoy.api.v2.core.Http2ProtocolOptions.SettingsParameter:-\x9a\xc5\x88\x1e(\n&envoy.api.v2.core.Http2ProtocolOptions\"\x8f\x01\n\x13GrpcProtocolOptions\x12J\n\x16http2_protocol_options\x18\x01 \x01(\x0b\x32*.envoy.config.core.v3.Http2ProtocolOptions:,\x9a\xc5\x88\x1e\'\n%envoy.api.v2.core.GrpcProtocolOptions\"\x16\n\x14Http3ProtocolOptionsB=\n\"io.envoyproxy.envoy.config.core.v3B\rProtocolProtoP\x01\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3'
  ,
  dependencies=[envoy_dot_type_dot_v3_dot_percent__pb2.DESCRIPTOR,google_dot_protobuf_dot_duration__pb2.DESCRIPTOR,google_dot_protobuf_dot_wrappers__pb2.DESCRIPTOR,udpa_dot_annotations_dot_status__pb2.DESCRIPTOR,udpa_dot_annotations_dot_versioning__pb2.DESCRIPTOR,validate_dot_validate__pb2.DESCRIPTOR,])



_HTTPPROTOCOLOPTIONS_HEADERSWITHUNDERSCORESACTION = _descriptor.EnumDescriptor(
  name='HeadersWithUnderscoresAction',
  full_name='envoy.config.core.v3.HttpProtocolOptions.HeadersWithUnderscoresAction',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='ALLOW', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='REJECT_REQUEST', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DROP_HEADER', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=813,
  serialized_end=891,
)
_sym_db.RegisterEnumDescriptor(_HTTPPROTOCOLOPTIONS_HEADERSWITHUNDERSCORESACTION)


_TCPPROTOCOLOPTIONS = _descriptor.Descriptor(
  name='TcpProtocolOptions',
  full_name='envoy.config.core.v3.TcpProtocolOptions',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036&\n$envoy.api.v2.core.TcpProtocolOptions',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=245,
  serialized_end=310,
)


_UPSTREAMHTTPPROTOCOLOPTIONS = _descriptor.Descriptor(
  name='UpstreamHttpProtocolOptions',
  full_name='envoy.config.core.v3.UpstreamHttpProtocolOptions',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='auto_sni', full_name='envoy.config.core.v3.UpstreamHttpProtocolOptions.auto_sni', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='auto_san_validation', full_name='envoy.config.core.v3.UpstreamHttpProtocolOptions.auto_san_validation', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036/\n-envoy.api.v2.core.UpstreamHttpProtocolOptions',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=313,
  serialized_end=443,
)


_HTTPPROTOCOLOPTIONS = _descriptor.Descriptor(
  name='HttpProtocolOptions',
  full_name='envoy.config.core.v3.HttpProtocolOptions',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='idle_timeout', full_name='envoy.config.core.v3.HttpProtocolOptions.idle_timeout', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_connection_duration', full_name='envoy.config.core.v3.HttpProtocolOptions.max_connection_duration', index=1,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_headers_count', full_name='envoy.config.core.v3.HttpProtocolOptions.max_headers_count', index=2,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004*\002(\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_stream_duration', full_name='envoy.config.core.v3.HttpProtocolOptions.max_stream_duration', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='headers_with_underscores_action', full_name='envoy.config.core.v3.HttpProtocolOptions.headers_with_underscores_action', index=4,
      number=5, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _HTTPPROTOCOLOPTIONS_HEADERSWITHUNDERSCORESACTION,
  ],
  serialized_options=b'\232\305\210\036\'\n%envoy.api.v2.core.HttpProtocolOptions',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=446,
  serialized_end=937,
)


_HTTP1PROTOCOLOPTIONS_HEADERKEYFORMAT_PROPERCASEWORDS = _descriptor.Descriptor(
  name='ProperCaseWords',
  full_name='envoy.config.core.v3.Http1ProtocolOptions.HeaderKeyFormat.ProperCaseWords',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036H\nFenvoy.api.v2.core.Http1ProtocolOptions.HeaderKeyFormat.ProperCaseWords',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1428,
  serialized_end=1524,
)

_HTTP1PROTOCOLOPTIONS_HEADERKEYFORMAT = _descriptor.Descriptor(
  name='HeaderKeyFormat',
  full_name='envoy.config.core.v3.Http1ProtocolOptions.HeaderKeyFormat',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='proper_case_words', full_name='envoy.config.core.v3.Http1ProtocolOptions.HeaderKeyFormat.proper_case_words', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_HTTP1PROTOCOLOPTIONS_HEADERKEYFORMAT_PROPERCASEWORDS, ],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\0368\n6envoy.api.v2.core.Http1ProtocolOptions.HeaderKeyFormat',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='header_format', full_name='envoy.config.core.v3.Http1ProtocolOptions.HeaderKeyFormat.header_format',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[], serialized_options=b'\370B\001'),
  ],
  serialized_start=1304,
  serialized_end=1609,
)

_HTTP1PROTOCOLOPTIONS = _descriptor.Descriptor(
  name='Http1ProtocolOptions',
  full_name='envoy.config.core.v3.Http1ProtocolOptions',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='allow_absolute_url', full_name='envoy.config.core.v3.Http1ProtocolOptions.allow_absolute_url', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='accept_http_10', full_name='envoy.config.core.v3.Http1ProtocolOptions.accept_http_10', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='default_host_for_http_10', full_name='envoy.config.core.v3.Http1ProtocolOptions.default_host_for_http_10', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='header_key_format', full_name='envoy.config.core.v3.Http1ProtocolOptions.header_key_format', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='enable_trailers', full_name='envoy.config.core.v3.Http1ProtocolOptions.enable_trailers', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='allow_chunked_length', full_name='envoy.config.core.v3.Http1ProtocolOptions.allow_chunked_length', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='override_stream_error_on_invalid_http_message', full_name='envoy.config.core.v3.Http1ProtocolOptions.override_stream_error_on_invalid_http_message', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_HTTP1PROTOCOLOPTIONS_HEADERKEYFORMAT, ],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036(\n&envoy.api.v2.core.Http1ProtocolOptions',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=940,
  serialized_end=1656,
)


_KEEPALIVESETTINGS = _descriptor.Descriptor(
  name='KeepaliveSettings',
  full_name='envoy.config.core.v3.KeepaliveSettings',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='interval', full_name='envoy.config.core.v3.KeepaliveSettings.interval', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\013\252\001\010\010\0012\004\020\300\204=', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timeout', full_name='envoy.config.core.v3.KeepaliveSettings.timeout', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\013\252\001\010\010\0012\004\020\300\204=', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='interval_jitter', full_name='envoy.config.core.v3.KeepaliveSettings.interval_jitter', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1659,
  serialized_end=1848,
)


_HTTP2PROTOCOLOPTIONS_SETTINGSPARAMETER = _descriptor.Descriptor(
  name='SettingsParameter',
  full_name='envoy.config.core.v3.Http2ProtocolOptions.SettingsParameter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='identifier', full_name='envoy.config.core.v3.Http2ProtocolOptions.SettingsParameter.identifier', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\010*\006\030\377\377\003(\000\372B\005\212\001\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='envoy.config.core.v3.Http2ProtocolOptions.SettingsParameter.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\212\001\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036:\n8envoy.api.v2.core.Http2ProtocolOptions.SettingsParameter',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2942,
  serialized_end=3152,
)

_HTTP2PROTOCOLOPTIONS = _descriptor.Descriptor(
  name='Http2ProtocolOptions',
  full_name='envoy.config.core.v3.Http2ProtocolOptions',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='hpack_table_size', full_name='envoy.config.core.v3.Http2ProtocolOptions.hpack_table_size', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_concurrent_streams', full_name='envoy.config.core.v3.Http2ProtocolOptions.max_concurrent_streams', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\n*\010\030\377\377\377\377\007(\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='initial_stream_window_size', full_name='envoy.config.core.v3.Http2ProtocolOptions.initial_stream_window_size', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\014*\n\030\377\377\377\377\007(\377\377\003', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='initial_connection_window_size', full_name='envoy.config.core.v3.Http2ProtocolOptions.initial_connection_window_size', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\014*\n\030\377\377\377\377\007(\377\377\003', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='allow_connect', full_name='envoy.config.core.v3.Http2ProtocolOptions.allow_connect', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='allow_metadata', full_name='envoy.config.core.v3.Http2ProtocolOptions.allow_metadata', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_outbound_frames', full_name='envoy.config.core.v3.Http2ProtocolOptions.max_outbound_frames', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004*\002(\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_outbound_control_frames', full_name='envoy.config.core.v3.Http2ProtocolOptions.max_outbound_control_frames', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004*\002(\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_consecutive_inbound_frames_with_empty_payload', full_name='envoy.config.core.v3.Http2ProtocolOptions.max_consecutive_inbound_frames_with_empty_payload', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_inbound_priority_frames_per_stream', full_name='envoy.config.core.v3.Http2ProtocolOptions.max_inbound_priority_frames_per_stream', index=9,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_inbound_window_update_frames_per_data_frame_sent', full_name='envoy.config.core.v3.Http2ProtocolOptions.max_inbound_window_update_frames_per_data_frame_sent', index=10,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004*\002(\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stream_error_on_invalid_http_messaging', full_name='envoy.config.core.v3.Http2ProtocolOptions.stream_error_on_invalid_http_messaging', index=11,
      number=12, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\030\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='override_stream_error_on_invalid_http_message', full_name='envoy.config.core.v3.Http2ProtocolOptions.override_stream_error_on_invalid_http_message', index=12,
      number=14, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='custom_settings_parameters', full_name='envoy.config.core.v3.Http2ProtocolOptions.custom_settings_parameters', index=13,
      number=13, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='connection_keepalive', full_name='envoy.config.core.v3.Http2ProtocolOptions.connection_keepalive', index=14,
      number=15, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_HTTP2PROTOCOLOPTIONS_SETTINGSPARAMETER, ],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036(\n&envoy.api.v2.core.Http2ProtocolOptions',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1851,
  serialized_end=3199,
)


_GRPCPROTOCOLOPTIONS = _descriptor.Descriptor(
  name='GrpcProtocolOptions',
  full_name='envoy.config.core.v3.GrpcProtocolOptions',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='http2_protocol_options', full_name='envoy.config.core.v3.GrpcProtocolOptions.http2_protocol_options', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036\'\n%envoy.api.v2.core.GrpcProtocolOptions',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3202,
  serialized_end=3345,
)


_HTTP3PROTOCOLOPTIONS = _descriptor.Descriptor(
  name='Http3ProtocolOptions',
  full_name='envoy.config.core.v3.Http3ProtocolOptions',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3347,
  serialized_end=3369,
)

_HTTPPROTOCOLOPTIONS.fields_by_name['idle_timeout'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_HTTPPROTOCOLOPTIONS.fields_by_name['max_connection_duration'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_HTTPPROTOCOLOPTIONS.fields_by_name['max_headers_count'].message_type = google_dot_protobuf_dot_wrappers__pb2._UINT32VALUE
_HTTPPROTOCOLOPTIONS.fields_by_name['max_stream_duration'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_HTTPPROTOCOLOPTIONS.fields_by_name['headers_with_underscores_action'].enum_type = _HTTPPROTOCOLOPTIONS_HEADERSWITHUNDERSCORESACTION
_HTTPPROTOCOLOPTIONS_HEADERSWITHUNDERSCORESACTION.containing_type = _HTTPPROTOCOLOPTIONS
_HTTP1PROTOCOLOPTIONS_HEADERKEYFORMAT_PROPERCASEWORDS.containing_type = _HTTP1PROTOCOLOPTIONS_HEADERKEYFORMAT
_HTTP1PROTOCOLOPTIONS_HEADERKEYFORMAT.fields_by_name['proper_case_words'].message_type = _HTTP1PROTOCOLOPTIONS_HEADERKEYFORMAT_PROPERCASEWORDS
_HTTP1PROTOCOLOPTIONS_HEADERKEYFORMAT.containing_type = _HTTP1PROTOCOLOPTIONS
_HTTP1PROTOCOLOPTIONS_HEADERKEYFORMAT.oneofs_by_name['header_format'].fields.append(
  _HTTP1PROTOCOLOPTIONS_HEADERKEYFORMAT.fields_by_name['proper_case_words'])
_HTTP1PROTOCOLOPTIONS_HEADERKEYFORMAT.fields_by_name['proper_case_words'].containing_oneof = _HTTP1PROTOCOLOPTIONS_HEADERKEYFORMAT.oneofs_by_name['header_format']
_HTTP1PROTOCOLOPTIONS.fields_by_name['allow_absolute_url'].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
_HTTP1PROTOCOLOPTIONS.fields_by_name['header_key_format'].message_type = _HTTP1PROTOCOLOPTIONS_HEADERKEYFORMAT
_HTTP1PROTOCOLOPTIONS.fields_by_name['override_stream_error_on_invalid_http_message'].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
_KEEPALIVESETTINGS.fields_by_name['interval'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_KEEPALIVESETTINGS.fields_by_name['timeout'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_KEEPALIVESETTINGS.fields_by_name['interval_jitter'].message_type = envoy_dot_type_dot_v3_dot_percent__pb2._PERCENT
_HTTP2PROTOCOLOPTIONS_SETTINGSPARAMETER.fields_by_name['identifier'].message_type = google_dot_protobuf_dot_wrappers__pb2._UINT32VALUE
_HTTP2PROTOCOLOPTIONS_SETTINGSPARAMETER.fields_by_name['value'].message_type = google_dot_protobuf_dot_wrappers__pb2._UINT32VALUE
_HTTP2PROTOCOLOPTIONS_SETTINGSPARAMETER.containing_type = _HTTP2PROTOCOLOPTIONS
_HTTP2PROTOCOLOPTIONS.fields_by_name['hpack_table_size'].message_type = google_dot_protobuf_dot_wrappers__pb2._UINT32VALUE
_HTTP2PROTOCOLOPTIONS.fields_by_name['max_concurrent_streams'].message_type = google_dot_protobuf_dot_wrappers__pb2._UINT32VALUE
_HTTP2PROTOCOLOPTIONS.fields_by_name['initial_stream_window_size'].message_type = google_dot_protobuf_dot_wrappers__pb2._UINT32VALUE
_HTTP2PROTOCOLOPTIONS.fields_by_name['initial_connection_window_size'].message_type = google_dot_protobuf_dot_wrappers__pb2._UINT32VALUE
_HTTP2PROTOCOLOPTIONS.fields_by_name['max_outbound_frames'].message_type = google_dot_protobuf_dot_wrappers__pb2._UINT32VALUE
_HTTP2PROTOCOLOPTIONS.fields_by_name['max_outbound_control_frames'].message_type = google_dot_protobuf_dot_wrappers__pb2._UINT32VALUE
_HTTP2PROTOCOLOPTIONS.fields_by_name['max_consecutive_inbound_frames_with_empty_payload'].message_type = google_dot_protobuf_dot_wrappers__pb2._UINT32VALUE
_HTTP2PROTOCOLOPTIONS.fields_by_name['max_inbound_priority_frames_per_stream'].message_type = google_dot_protobuf_dot_wrappers__pb2._UINT32VALUE
_HTTP2PROTOCOLOPTIONS.fields_by_name['max_inbound_window_update_frames_per_data_frame_sent'].message_type = google_dot_protobuf_dot_wrappers__pb2._UINT32VALUE
_HTTP2PROTOCOLOPTIONS.fields_by_name['override_stream_error_on_invalid_http_message'].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
_HTTP2PROTOCOLOPTIONS.fields_by_name['custom_settings_parameters'].message_type = _HTTP2PROTOCOLOPTIONS_SETTINGSPARAMETER
_HTTP2PROTOCOLOPTIONS.fields_by_name['connection_keepalive'].message_type = _KEEPALIVESETTINGS
_GRPCPROTOCOLOPTIONS.fields_by_name['http2_protocol_options'].message_type = _HTTP2PROTOCOLOPTIONS
DESCRIPTOR.message_types_by_name['TcpProtocolOptions'] = _TCPPROTOCOLOPTIONS
DESCRIPTOR.message_types_by_name['UpstreamHttpProtocolOptions'] = _UPSTREAMHTTPPROTOCOLOPTIONS
DESCRIPTOR.message_types_by_name['HttpProtocolOptions'] = _HTTPPROTOCOLOPTIONS
DESCRIPTOR.message_types_by_name['Http1ProtocolOptions'] = _HTTP1PROTOCOLOPTIONS
DESCRIPTOR.message_types_by_name['KeepaliveSettings'] = _KEEPALIVESETTINGS
DESCRIPTOR.message_types_by_name['Http2ProtocolOptions'] = _HTTP2PROTOCOLOPTIONS
DESCRIPTOR.message_types_by_name['GrpcProtocolOptions'] = _GRPCPROTOCOLOPTIONS
DESCRIPTOR.message_types_by_name['Http3ProtocolOptions'] = _HTTP3PROTOCOLOPTIONS
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

TcpProtocolOptions = _reflection.GeneratedProtocolMessageType('TcpProtocolOptions', (_message.Message,), {
  'DESCRIPTOR' : _TCPPROTOCOLOPTIONS,
  '__module__' : 'envoy.config.core.v3.protocol_pb2'
  # @@protoc_insertion_point(class_scope:envoy.config.core.v3.TcpProtocolOptions)
  })
_sym_db.RegisterMessage(TcpProtocolOptions)

UpstreamHttpProtocolOptions = _reflection.GeneratedProtocolMessageType('UpstreamHttpProtocolOptions', (_message.Message,), {
  'DESCRIPTOR' : _UPSTREAMHTTPPROTOCOLOPTIONS,
  '__module__' : 'envoy.config.core.v3.protocol_pb2'
  # @@protoc_insertion_point(class_scope:envoy.config.core.v3.UpstreamHttpProtocolOptions)
  })
_sym_db.RegisterMessage(UpstreamHttpProtocolOptions)

HttpProtocolOptions = _reflection.GeneratedProtocolMessageType('HttpProtocolOptions', (_message.Message,), {
  'DESCRIPTOR' : _HTTPPROTOCOLOPTIONS,
  '__module__' : 'envoy.config.core.v3.protocol_pb2'
  # @@protoc_insertion_point(class_scope:envoy.config.core.v3.HttpProtocolOptions)
  })
_sym_db.RegisterMessage(HttpProtocolOptions)

Http1ProtocolOptions = _reflection.GeneratedProtocolMessageType('Http1ProtocolOptions', (_message.Message,), {

  'HeaderKeyFormat' : _reflection.GeneratedProtocolMessageType('HeaderKeyFormat', (_message.Message,), {

    'ProperCaseWords' : _reflection.GeneratedProtocolMessageType('ProperCaseWords', (_message.Message,), {
      'DESCRIPTOR' : _HTTP1PROTOCOLOPTIONS_HEADERKEYFORMAT_PROPERCASEWORDS,
      '__module__' : 'envoy.config.core.v3.protocol_pb2'
      # @@protoc_insertion_point(class_scope:envoy.config.core.v3.Http1ProtocolOptions.HeaderKeyFormat.ProperCaseWords)
      })
    ,
    'DESCRIPTOR' : _HTTP1PROTOCOLOPTIONS_HEADERKEYFORMAT,
    '__module__' : 'envoy.config.core.v3.protocol_pb2'
    # @@protoc_insertion_point(class_scope:envoy.config.core.v3.Http1ProtocolOptions.HeaderKeyFormat)
    })
  ,
  'DESCRIPTOR' : _HTTP1PROTOCOLOPTIONS,
  '__module__' : 'envoy.config.core.v3.protocol_pb2'
  # @@protoc_insertion_point(class_scope:envoy.config.core.v3.Http1ProtocolOptions)
  })
_sym_db.RegisterMessage(Http1ProtocolOptions)
_sym_db.RegisterMessage(Http1ProtocolOptions.HeaderKeyFormat)
_sym_db.RegisterMessage(Http1ProtocolOptions.HeaderKeyFormat.ProperCaseWords)

KeepaliveSettings = _reflection.GeneratedProtocolMessageType('KeepaliveSettings', (_message.Message,), {
  'DESCRIPTOR' : _KEEPALIVESETTINGS,
  '__module__' : 'envoy.config.core.v3.protocol_pb2'
  # @@protoc_insertion_point(class_scope:envoy.config.core.v3.KeepaliveSettings)
  })
_sym_db.RegisterMessage(KeepaliveSettings)

Http2ProtocolOptions = _reflection.GeneratedProtocolMessageType('Http2ProtocolOptions', (_message.Message,), {

  'SettingsParameter' : _reflection.GeneratedProtocolMessageType('SettingsParameter', (_message.Message,), {
    'DESCRIPTOR' : _HTTP2PROTOCOLOPTIONS_SETTINGSPARAMETER,
    '__module__' : 'envoy.config.core.v3.protocol_pb2'
    # @@protoc_insertion_point(class_scope:envoy.config.core.v3.Http2ProtocolOptions.SettingsParameter)
    })
  ,
  'DESCRIPTOR' : _HTTP2PROTOCOLOPTIONS,
  '__module__' : 'envoy.config.core.v3.protocol_pb2'
  # @@protoc_insertion_point(class_scope:envoy.config.core.v3.Http2ProtocolOptions)
  })
_sym_db.RegisterMessage(Http2ProtocolOptions)
_sym_db.RegisterMessage(Http2ProtocolOptions.SettingsParameter)

GrpcProtocolOptions = _reflection.GeneratedProtocolMessageType('GrpcProtocolOptions', (_message.Message,), {
  'DESCRIPTOR' : _GRPCPROTOCOLOPTIONS,
  '__module__' : 'envoy.config.core.v3.protocol_pb2'
  # @@protoc_insertion_point(class_scope:envoy.config.core.v3.GrpcProtocolOptions)
  })
_sym_db.RegisterMessage(GrpcProtocolOptions)

Http3ProtocolOptions = _reflection.GeneratedProtocolMessageType('Http3ProtocolOptions', (_message.Message,), {
  'DESCRIPTOR' : _HTTP3PROTOCOLOPTIONS,
  '__module__' : 'envoy.config.core.v3.protocol_pb2'
  # @@protoc_insertion_point(class_scope:envoy.config.core.v3.Http3ProtocolOptions)
  })
_sym_db.RegisterMessage(Http3ProtocolOptions)


DESCRIPTOR._options = None
_TCPPROTOCOLOPTIONS._options = None
_UPSTREAMHTTPPROTOCOLOPTIONS._options = None
_HTTPPROTOCOLOPTIONS.fields_by_name['max_headers_count']._options = None
_HTTPPROTOCOLOPTIONS._options = None
_HTTP1PROTOCOLOPTIONS_HEADERKEYFORMAT_PROPERCASEWORDS._options = None
_HTTP1PROTOCOLOPTIONS_HEADERKEYFORMAT.oneofs_by_name['header_format']._options = None
_HTTP1PROTOCOLOPTIONS_HEADERKEYFORMAT._options = None
_HTTP1PROTOCOLOPTIONS._options = None
_KEEPALIVESETTINGS.fields_by_name['interval']._options = None
_KEEPALIVESETTINGS.fields_by_name['timeout']._options = None
_HTTP2PROTOCOLOPTIONS_SETTINGSPARAMETER.fields_by_name['identifier']._options = None
_HTTP2PROTOCOLOPTIONS_SETTINGSPARAMETER.fields_by_name['value']._options = None
_HTTP2PROTOCOLOPTIONS_SETTINGSPARAMETER._options = None
_HTTP2PROTOCOLOPTIONS.fields_by_name['max_concurrent_streams']._options = None
_HTTP2PROTOCOLOPTIONS.fields_by_name['initial_stream_window_size']._options = None
_HTTP2PROTOCOLOPTIONS.fields_by_name['initial_connection_window_size']._options = None
_HTTP2PROTOCOLOPTIONS.fields_by_name['max_outbound_frames']._options = None
_HTTP2PROTOCOLOPTIONS.fields_by_name['max_outbound_control_frames']._options = None
_HTTP2PROTOCOLOPTIONS.fields_by_name['max_inbound_window_update_frames_per_data_frame_sent']._options = None
_HTTP2PROTOCOLOPTIONS.fields_by_name['stream_error_on_invalid_http_messaging']._options = None
_HTTP2PROTOCOLOPTIONS._options = None
_GRPCPROTOCOLOPTIONS._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/service/discovery/v3/ads.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.service.discovery.v3 import discovery_pb2 as envoy_dot_service_dot_discovery_dot_v3_dot_discovery__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from udpa.annotations import versioning_pb2 as udpa_dot_annotations_dot_versioning__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='envoy/service/discovery/v3/ads.proto',
  package='envoy.service.discovery.v3',
  syntax='proto3',
  serialized_options=b'\n(io.envoyproxy.envoy.service.discovery.v3B\010AdsProtoP\001\210\001\001\272\200\310\321\006\002\020\002',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n$envoy/service/discovery/v3/ads.proto\x12\x1a\x65nvoy.service.discovery.v3\x1a*envoy/service/discovery/v3/discovery.proto\x1a\x1dudpa/annotations/status.proto\x1a!udpa/annotations/versioning.proto\"6\n\x08\x41\x64sDummy:*\x9a\xc5\x88\x1e%\n#envoy.service.discovery.v2.AdsDummy2\xa6\x02\n\x1a\x41ggregatedDiscoveryService\x12~\n\x19StreamAggregatedResources\x12,.envoy.service.discovery.v3.DiscoveryRequest\x1a-.envoy.service.discovery.v3.DiscoveryResponse\"\x00(\x01\x30\x01\x12\x87\x01\n\x18\x44\x65ltaAggregatedResources\x12\x31.envoy.service.discovery.v3.DeltaDiscoveryRequest\x1a\x32.envoy.service.discovery.v3.DeltaDiscoveryResponse\"\x00(\x01\x30\x01\x42\x41\n(io.envoyproxy.envoy.service.discovery.v3B\x08\x41\x64sProtoP\x01\x88\x01\x01\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3'
  ,
  dependencies=[envoy_dot_service_dot_discovery_dot_v3_dot_discovery__pb2.DESCRIPTOR,udpa_dot_annotations_dot_status__pb2.DESCRIPTOR,udpa_dot_annotations_dot_versioning__pb2.DESCRIPTOR,])




_ADSDUMMY = _descriptor.Descriptor(
  name='AdsDummy',
  full_name='envoy.service.discovery.v3.AdsDummy',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036%\n#envoy.service.discovery.v2.AdsDummy',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=178,
  serialized_end=232,
)

DESCRIPTOR.message_types_by_name['AdsDummy'] = _ADSDUMMY
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

AdsDummy = _reflection.GeneratedProtocolMessageType('AdsDummy', (_message.Message,), {
  'DESCRIPTOR' : _ADSDUMMY,
  '__module__' : 'envoy.service.discovery.v3.ads_pb2'
  # @@protoc_insertion_point(class_scope:envoy.service.discovery.v3.AdsDummy)
  })
_sym_db.RegisterMessage(AdsDummy)


DESCRIPTOR._options = None
_ADSDUMMY._options = None

_AGGREGATEDDISCOVERYSERVICE = _descriptor.ServiceDescriptor(
  name='AggregatedDiscoveryService',
  full_name='envoy.service.discovery.v3.AggregatedDiscoveryService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=235,
  serialized_end=529,
  methods=[
  _descriptor.MethodDescriptor(
    name='StreamAggregatedResources',
    full_name='envoy.service.discovery.v3.AggregatedDiscoveryService.StreamAggregatedResources',
    index=0,
    containing_service=None,
    input_type=envoy_dot_service_dot_discovery_dot_v3_dot_discovery__pb2._DISCOVERYREQUEST,
    output_type=envoy_dot_service_dot_discovery_dot_v3_dot_discovery__pb2._DISCOVERYRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DeltaAggregatedResources',
    full_name='envoy.service.discovery.v3.AggregatedDiscoveryService.DeltaAggregatedResources',
    index=1,
    containing_service=None,
    input_type=envoy_dot_service_dot_discovery_dot_v3_dot_discovery__pb2._DELTADISCOVERYREQUEST,
    output_type=envoy_dot_service_dot_discovery_dot_v3_dot_discovery__pb2._DELTADISCOVERYRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_AGGREGATEDDISCOVERYSERVICE)

DESCRIPTOR.services_by_name['AggregatedDiscoveryService'] = _AGGREGATEDDISCOVERYSERVICE

# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/logging/v2/logging_metrics.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import distribution_pb2 as google_dot_api_dot_distribution__pb2
from google.api import metric_pb2 as google_dot_api_dot_metric__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.api import client_pb2 as google_dot_api_dot_client__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='google/logging/v2/logging_metrics.proto',
  package='google.logging.v2',
  syntax='proto3',
  serialized_options=b'\n\025com.google.logging.v2B\023LoggingMetricsProtoP\001Z8google.golang.org/genproto/googleapis/logging/v2;logging\370\001\001\252\002\027Google.Cloud.Logging.V2\312\002\027Google\\Cloud\\Logging\\V2',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\'google/logging/v2/logging_metrics.proto\x12\x11google.logging.v2\x1a\x1dgoogle/api/distribution.proto\x1a\x17google/api/metric.proto\x1a\x1bgoogle/protobuf/empty.proto\x1a google/protobuf/field_mask.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1cgoogle/api/annotations.proto\x1a\x17google/api/client.proto\"\x93\x04\n\tLogMetric\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x0e\n\x06\x66ilter\x18\x03 \x01(\t\x12\x37\n\x11metric_descriptor\x18\x05 \x01(\x0b\x32\x1c.google.api.MetricDescriptor\x12\x17\n\x0fvalue_extractor\x18\x06 \x01(\t\x12K\n\x10label_extractors\x18\x07 \x03(\x0b\x32\x31.google.logging.v2.LogMetric.LabelExtractorsEntry\x12>\n\x0e\x62ucket_options\x18\x08 \x01(\x0b\x32&.google.api.Distribution.BucketOptions\x12/\n\x0b\x63reate_time\x18\t \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12/\n\x0bupdate_time\x18\n \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12<\n\x07version\x18\x04 \x01(\x0e\x32\'.google.logging.v2.LogMetric.ApiVersionB\x02\x18\x01\x1a\x36\n\x14LabelExtractorsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x1c\n\nApiVersion\x12\x06\n\x02V2\x10\x00\x12\x06\n\x02V1\x10\x01\"N\n\x15ListLogMetricsRequest\x12\x0e\n\x06parent\x18\x01 \x01(\t\x12\x12\n\npage_token\x18\x02 \x01(\t\x12\x11\n\tpage_size\x18\x03 \x01(\x05\"`\n\x16ListLogMetricsResponse\x12-\n\x07metrics\x18\x01 \x03(\x0b\x32\x1c.google.logging.v2.LogMetric\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"*\n\x13GetLogMetricRequest\x12\x13\n\x0bmetric_name\x18\x01 \x01(\t\"V\n\x16\x43reateLogMetricRequest\x12\x0e\n\x06parent\x18\x01 \x01(\t\x12,\n\x06metric\x18\x02 \x01(\x0b\x32\x1c.google.logging.v2.LogMetric\"[\n\x16UpdateLogMetricRequest\x12\x13\n\x0bmetric_name\x18\x01 \x01(\t\x12,\n\x06metric\x18\x02 \x01(\x0b\x32\x1c.google.logging.v2.LogMetric\"-\n\x16\x44\x65leteLogMetricRequest\x12\x13\n\x0bmetric_name\x18\x01 \x01(\t2\xe4\x07\n\x10MetricsServiceV2\x12\x8e\x01\n\x0eListLogMetrics\x12(.google.logging.v2.ListLogMetricsRequest\x1a).google.logging.v2.ListLogMetricsResponse\"\'\x82\xd3\xe4\x93\x02!\x12\x1f/v2/{parent=projects/*}/metrics\x12\x84\x01\n\x0cGetLogMetric\x12&.google.logging.v2.GetLogMetricRequest\x1a\x1c.google.logging.v2.LogMetric\".\x82\xd3\xe4\x93\x02(\x12&/v2/{metric_name=projects/*/metrics/*}\x12\x8b\x01\n\x0f\x43reateLogMetric\x12).google.logging.v2.CreateLogMetricRequest\x1a\x1c.google.logging.v2.LogMetric\"/\x82\xd3\xe4\x93\x02)\"\x1f/v2/{parent=projects/*}/metrics:\x06metric\x12\x92\x01\n\x0fUpdateLogMetric\x12).google.logging.v2.UpdateLogMetricRequest\x1a\x1c.google.logging.v2.LogMetric\"6\x82\xd3\xe4\x93\x02\x30\x1a&/v2/{metric_name=projects/*/metrics/*}:\x06metric\x12\x84\x01\n\x0f\x44\x65leteLogMetric\x12).google.logging.v2.DeleteLogMetricRequest\x1a\x16.google.protobuf.Empty\".\x82\xd3\xe4\x93\x02(*&/v2/{metric_name=projects/*/metrics/*}\x1a\x8d\x02\xca\x41\x16logging.googleapis.com\xd2\x41\xf0\x01https://www.googleapis.com/auth/cloud-platform,https://www.googleapis.com/auth/cloud-platform.read-only,https://www.googleapis.com/auth/logging.admin,https://www.googleapis.com/auth/logging.read,https://www.googleapis.com/auth/logging.writeB\x9f\x01\n\x15\x63om.google.logging.v2B\x13LoggingMetricsProtoP\x01Z8google.golang.org/genproto/googleapis/logging/v2;logging\xf8\x01\x01\xaa\x02\x17Google.Cloud.Logging.V2\xca\x02\x17Google\\Cloud\\Logging\\V2b\x06proto3'
  ,
  dependencies=[google_dot_api_dot_distribution__pb2.DESCRIPTOR,google_dot_api_dot_metric__pb2.DESCRIPTOR,google_dot_protobuf_dot_empty__pb2.DESCRIPTOR,google_dot_protobuf_dot_field__mask__pb2.DESCRIPTOR,google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,google_dot_api_dot_annotations__pb2.DESCRIPTOR,google_dot_api_dot_client__pb2.DESCRIPTOR,])



_LOGMETRIC_APIVERSION = _descriptor.EnumDescriptor(
  name='ApiVersion',
  full_name='google.logging.v2.LogMetric.ApiVersion',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='V2', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='V1', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=773,
  serialized_end=801,
)
_sym_db.RegisterEnumDescriptor(_LOGMETRIC_APIVERSION)


_LOGMETRIC_LABELEXTRACTORSENTRY = _descriptor.Descriptor(
  name='LabelExtractorsEntry',
  full_name='google.logging.v2.LogMetric.LabelExtractorsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='google.logging.v2.LogMetric.LabelExtractorsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='google.logging.v2.LogMetric.LabelExtractorsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=717,
  serialized_end=771,
)

_LOGMETRIC = _descriptor.Descriptor(
  name='LogMetric',
  full_name='google.logging.v2.LogMetric',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='google.logging.v2.LogMetric.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='google.logging.v2.LogMetric.description', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='filter', full_name='google.logging.v2.LogMetric.filter', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='metric_descriptor', full_name='google.logging.v2.LogMetric.metric_descriptor', index=3,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value_extractor', full_name='google.logging.v2.LogMetric.value_extractor', index=4,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='label_extractors', full_name='google.logging.v2.LogMetric.label_extractors', index=5,
      number=7, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='bucket_options', full_name='google.logging.v2.LogMetric.bucket_options', index=6,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='create_time', full_name='google.logging.v2.LogMetric.create_time', index=7,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='update_time', full_name='google.logging.v2.LogMetric.update_time', index=8,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='version', full_name='google.logging.v2.LogMetric.version', index=9,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\030\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_LOGMETRIC_LABELEXTRACTORSENTRY, ],
  enum_types=[
    _LOGMETRIC_APIVERSION,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=270,
  serialized_end=801,
)


_LISTLOGMETRICSREQUEST = _descriptor.Descriptor(
  name='ListLogMetricsRequest',
  full_name='google.logging.v2.ListLogMetricsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='parent', full_name='google.logging.v2.ListLogMetricsRequest.parent', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_token', full_name='google.logging.v2.ListLogMetricsRequest.page_token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_size', full_name='google.logging.v2.ListLogMetricsRequest.page_size', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=803,
  serialized_end=881,
)


_LISTLOGMETRICSRESPONSE = _descriptor.Descriptor(
  name='ListLogMetricsResponse',
  full_name='google.logging.v2.ListLogMetricsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='metrics', full_name='google.logging.v2.ListLogMetricsResponse.metrics', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='next_page_token', full_name='google.logging.v2.ListLogMetricsResponse.next_page_token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=883,
  serialized_end=979,
)


_GETLOGMETRICREQUEST = _descriptor.Descriptor(
  name='GetLogMetricRequest',
  full_name='google.logging.v2.GetLogMetricRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='metric_name', full_name='google.logging.v2.GetLogMetricRequest.metric_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=981,
  serialized_end=1023,
)


_CREATELOGMETRICREQUEST = _descriptor.Descriptor(
  name='CreateLogMetricRequest',
  full_name='google.logging.v2.CreateLogMetricRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='parent', full_name='google.logging.v2.CreateLogMetricRequest.parent', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='metric', full_name='google.logging.v2.CreateLogMetricRequest.metric', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1025,
  serialized_end=1111,
)


_UPDATELOGMETRICREQUEST = _descriptor.Descriptor(
  name='UpdateLogMetricRequest',
  full_name='google.logging.v2.UpdateLogMetricRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='metric_name', full_name='google.logging.v2.UpdateLogMetricRequest.metric_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='metric', full_name='google.logging.v2.UpdateLogMetricRequest.metric', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1113,
  serialized_end=1204,
)


_DELETELOGMETRICREQUEST = _descriptor.Descriptor(
  name='DeleteLogMetricRequest',
  full_name='google.logging.v2.DeleteLogMetricRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='metric_name', full_name='google.logging.v2.DeleteLogMetricRequest.metric_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1206,
  serialized_end=1251,
)

_LOGMETRIC_LABELEXTRACTORSENTRY.containing_type = _LOGMETRIC
_LOGMETRIC.fields_by_name['metric_descriptor'].message_type = google_dot_api_dot_metric__pb2._METRICDESCRIPTOR
_LOGMETRIC.fields_by_name['label_extractors'].message_type = _LOGMETRIC_LABELEXTRACTORSENTRY
_LOGMETRIC.fields_by_name['bucket_options'].message_type = google_dot_api_dot_distribution__pb2._DISTRIBUTION_BUCKETOPTIONS
_LOGMETRIC.fields_by_name['create_time'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_LOGMETRIC.fields_by_name['update_time'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_LOGMETRIC.fields_by_name['version'].enum_type = _LOGMETRIC_APIVERSION
_LOGMETRIC_APIVERSION.containing_type = _LOGMETRIC
_LISTLOGMETRICSRESPONSE.fields_by_name['metrics'].message_type = _LOGMETRIC
_CREATELOGMETRICREQUEST.fields_by_name['metric'].message_type = _LOGMETRIC
_UPDATELOGMETRICREQUEST.fields_by_name['metric'].message_type = _LOGMETRIC
DESCRIPTOR.message_types_by_name['LogMetric'] = _LOGMETRIC
DESCRIPTOR.message_types_by_name['ListLogMetricsRequest'] = _LISTLOGMETRICSREQUEST
DESCRIPTOR.message_types_by_name['ListLogMetricsResponse'] = _LISTLOGMETRICSRESPONSE
DESCRIPTOR.message_types_by_name['GetLogMetricRequest'] = _GETLOGMETRICREQUEST
DESCRIPTOR.message_types_by_name['CreateLogMetricRequest'] = _CREATELOGMETRICREQUEST
DESCRIPTOR.message_types_by_name['UpdateLogMetricRequest'] = _UPDATELOGMETRICREQUEST
DESCRIPTOR.message_types_by_name['DeleteLogMetricRequest'] = _DELETELOGMETRICREQUEST
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

LogMetric = _reflection.GeneratedProtocolMessageType('LogMetric', (_message.Message,), {

  'LabelExtractorsEntry' : _reflection.GeneratedProtocolMessageType('LabelExtractorsEntry', (_message.Message,), {
    'DESCRIPTOR' : _LOGMETRIC_LABELEXTRACTORSENTRY,
    '__module__' : 'google.logging.v2.logging_metrics_pb2'
    # @@protoc_insertion_point(class_scope:google.logging.v2.LogMetric.LabelExtractorsEntry)
    })
  ,
  'DESCRIPTOR' : _LOGMETRIC,
  '__module__' : 'google.logging.v2.logging_metrics_pb2'
  # @@protoc_insertion_point(class_scope:google.logging.v2.LogMetric)
  })
_sym_db.RegisterMessage(LogMetric)
_sym_db.RegisterMessage(LogMetric.LabelExtractorsEntry)

ListLogMetricsRequest = _reflection.GeneratedProtocolMessageType('ListLogMetricsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTLOGMETRICSREQUEST,
  '__module__' : 'google.logging.v2.logging_metrics_pb2'
  # @@protoc_insertion_point(class_scope:google.logging.v2.ListLogMetricsRequest)
  })
_sym_db.RegisterMessage(ListLogMetricsRequest)

ListLogMetricsResponse = _reflection.GeneratedProtocolMessageType('ListLogMetricsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTLOGMETRICSRESPONSE,
  '__module__' : 'google.logging.v2.logging_metrics_pb2'
  # @@protoc_insertion_point(class_scope:google.logging.v2.ListLogMetricsResponse)
  })
_sym_db.RegisterMessage(ListLogMetricsResponse)

GetLogMetricRequest = _reflection.GeneratedProtocolMessageType('GetLogMetricRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETLOGMETRICREQUEST,
  '__module__' : 'google.logging.v2.logging_metrics_pb2'
  # @@protoc_insertion_point(class_scope:google.logging.v2.GetLogMetricRequest)
  })
_sym_db.RegisterMessage(GetLogMetricRequest)

CreateLogMetricRequest = _reflection.GeneratedProtocolMessageType('CreateLogMetricRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATELOGMETRICREQUEST,
  '__module__' : 'google.logging.v2.logging_metrics_pb2'
  # @@protoc_insertion_point(class_scope:google.logging.v2.CreateLogMetricRequest)
  })
_sym_db.RegisterMessage(CreateLogMetricRequest)

UpdateLogMetricRequest = _reflection.GeneratedProtocolMessageType('UpdateLogMetricRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATELOGMETRICREQUEST,
  '__module__' : 'google.logging.v2.logging_metrics_pb2'
  # @@protoc_insertion_point(class_scope:google.logging.v2.UpdateLogMetricRequest)
  })
_sym_db.RegisterMessage(UpdateLogMetricRequest)

DeleteLogMetricRequest = _reflection.GeneratedProtocolMessageType('DeleteLogMetricRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETELOGMETRICREQUEST,
  '__module__' : 'google.logging.v2.logging_metrics_pb2'
  # @@protoc_insertion_point(class_scope:google.logging.v2.DeleteLogMetricRequest)
  })
_sym_db.RegisterMessage(DeleteLogMetricRequest)


DESCRIPTOR._options = None
_LOGMETRIC_LABELEXTRACTORSENTRY._options = None
_LOGMETRIC.fields_by_name['version']._options = None

_METRICSSERVICEV2 = _descriptor.ServiceDescriptor(
  name='MetricsServiceV2',
  full_name='google.logging.v2.MetricsServiceV2',
  file=DESCRIPTOR,
  index=0,
  serialized_options=b'\312A\026logging.googleapis.com\322A\360\001https://www.googleapis.com/auth/cloud-platform,https://www.googleapis.com/auth/cloud-platform.read-only,https://www.googleapis.com/auth/logging.admin,https://www.googleapis.com/auth/logging.read,https://www.googleapis.com/auth/logging.write',
  create_key=_descriptor._internal_create_key,
  serialized_start=1254,
  serialized_end=2250,
  methods=[
  _descriptor.MethodDescriptor(
    name='ListLogMetrics',
    full_name='google.logging.v2.MetricsServiceV2.ListLogMetrics',
    index=0,
    containing_service=None,
    input_type=_LISTLOGMETRICSREQUEST,
    output_type=_LISTLOGMETRICSRESPONSE,
    serialized_options=b'\202\323\344\223\002!\022\037/v2/{parent=projects/*}/metrics',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetLogMetric',
    full_name='google.logging.v2.MetricsServiceV2.GetLogMetric',
    index=1,
    containing_service=None,
    input_type=_GETLOGMETRICREQUEST,
    output_type=_LOGMETRIC,
    serialized_options=b'\202\323\344\223\002(\022&/v2/{metric_name=projects/*/metrics/*}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='CreateLogMetric',
    full_name='google.logging.v2.MetricsServiceV2.CreateLogMetric',
    index=2,
    containing_service=None,
    input_type=_CREATELOGMETRICREQUEST,
    output_type=_LOGMETRIC,
    serialized_options=b'\202\323\344\223\002)\"\037/v2/{parent=projects/*}/metrics:\006metric',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UpdateLogMetric',
    full_name='google.logging.v2.MetricsServiceV2.UpdateLogMetric',
    index=3,
    containing_service=None,
    input_type=_UPDATELOGMETRICREQUEST,
    output_type=_LOGMETRIC,
    serialized_options=b'\202\323\344\223\0020\032&/v2/{metric_name=projects/*/metrics/*}:\006metric',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DeleteLogMetric',
    full_name='google.logging.v2.MetricsServiceV2.DeleteLogMetric',
    index=4,
    containing_service=None,
    input_type=_DELETELOGMETRICREQUEST,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=b'\202\323\344\223\002(*&/v2/{metric_name=projects/*/metrics/*}',
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_METRICSSERVICEV2)

DESCRIPTOR.services_by_name['MetricsServiceV2'] = _METRICSSERVICEV2

# @@protoc_insertion_point(module_scope)
